(function () {
  'use strict';

  angular.module('starter.controllers')
    .controller('HomeCtrl', HomeCtrl);

  HomeCtrl.$inject = ['$scope', '$ionicSlideBoxDelegate', '$state', '$ionicPopup', '$stateParams', 'dataService', 'localDataService'];

  function HomeCtrl ($scope, $ionicSlideBoxDelegate, $state, $ionicPopup, $stateParams, dataService, localDataService) {
    let _this = this;

    _this.toggleSearchPanel = toggleSearchPanel;
    _this.changeSearchTab = changeSearchTab;
    _this.selectDistrict = selectDistrict;
    _this.search = search;
    _this.order = order;
    _this.publish = publish;
    // _this.scan = scan;

    _this.param = {       // 查询参数
      status: -1,
      categoryId: '',     // 分类id
      keyword: '',        // 查询关键字
      district: '',       // 区
      minWage: '',        // 最低价格
      maxWage: '',        // 最高价格
      minVacancies: '',   // 最低人数
      maxVacancies: '',   // 最高人数
      pageNo: 0,         // 页码，从1开始
      pageSize: 20,      // 页长
      orderBy: 'wage', // 排序字段
      orderType: 'desc',   // 排序方式
      isReal: 1 // 只查询已审核通过的任务
    };
    _this.tasks = [];     // 任务列表
    _this.totalTasks = 0; // 总任务数
    _this.districts = [];   // 区列表
    _this.showSearchPanel = false; // 是否显示搜索框
    _this.searchTab = 'wage';         // wage, district, vacancies

    init();

    function init () {
      // 第一次运行APP，进入介绍页面
      if (!localStorage.getItem('intro')) {
        $state.go('intro');
        return;
      }
      // 查询任务列表
      $stateParams.categoryId && (_this.param.categoryId = $stateParams.categoryId);
      _this.search();

      // 查询区列表，暂时只支持苏州
      dataService.get('/area/320500')
        .then(function (resp) {
          _this.districts = resp.data;
        });

      if(!localDataService.getUser()){
        dataService.get('/user/currentUser')
          .then(function (resp) {
            _this.user = resp.data;
            localDataService.setUser(_this.user);
          });
      }else{
        _this.user = localDataService.getUser();
      }
    }

    /**
     * 显示/隐藏搜索框
     */
    function toggleSearchPanel (flag) {
      if (typeof flag == 'boolean') {
        _this.showSearchPanel = flag;
      } else {
        _this.showSearchPanel = !_this.showSearchPanel;
      }
    }

    /**
     * 切换查询tab
     */
    function changeSearchTab (tab) {
      _this.searchTab = tab;
    }

    /**
     * 切换区
     */
    function selectDistrict (district) {
      _this.param.district = district.id;
    }

    /**
     * 查询
     */
    function search () {
      _this.param.pageNo += 1;
      dataService.get('/task/pageList', _this.param)
        .then(function (resp) {
          if (resp && resp.data && resp.data.data) {
            _this.tasks = _this.tasks.concat(resp && resp.data && resp.data.data);
            _this.totalTasks = resp && resp.data && resp.data.total;
          }
          $scope.$broadcast('scroll.infiniteScrollComplete');
        });
    }

    /**
     * 排序
     * @param key
     */
    function order(key) {
      if (_this.param.orderBy != key) {
        _this.param.orderType = 'desc';
      } else {
        _this.param.orderType = _this.param.orderType == 'desc' ? 'asc' : 'desc';
      }
      _this.param.orderBy = key;
    }

    /**
     * 发布任务
     */
    function publish () {
      $state.go('tab.taskPublish',{
        taskId: null
      });
    }
  }
})();
