(function () {
    'use strict';

    angular.module('starter.controllers')
        .controller('ItemListCtrl', ItemListCtrl);

    ItemListCtrl.$inject = ['$scope', '$state', '$stateParams', '$ionicActionSheet', '$ionicPopup', 'dataService', 'localDataService'];

    function ItemListCtrl ($scope, $state, $stateParams, $ionicActionSheet, $ionicPopup, dataService, localDataService) {
        var _this = this;
        _this.listMode = '';
        _this.moreDataCanBeLoaded = true;

        _this.search = search;
        _this.changListMode = changListMode;
        _this.goToItem = goToItem;
        _this.loadMore = loadMore;
        _this.showStoreOptions = showStoreOptions;
        _this.showCategories = showCategories;
        _this.showContactStore = showContactStore;

        init();

        function init () {
            _this.searchCondition = localDataService.getSearchCondition();
            if (_this.searchCondition.searchType == 'goods') {
                _this.listMode = 'img';
            } else if (_this.searchCondition.searchType == 'store') {
                _this.listMode = 'list';
            }
            _this.searchUrl = '/search/' + (_this.searchCondition.searchType == 'store' ? 'stores' : _this.searchCondition.searchType);
            _this.formatSearchCondition = _formatSearchCondition();
            _this.formatSearchCondition.start = 0;
            search();
            if (_this.searchCondition.storeId) {
                // todo
                /*dataService.get('/stores/'  + _this.storeId + '/categories')
                    .then(function (resp) {
                        _this.categories = resp.categories;
                    });*/
                _this.categories = [
                    {"id": 1, "name": "人物"},
                    {"id": 2, "name": "鸟兽"},
                    {"id": 3, "name": "蔬菜"},
                    {"id": 4, "name": "情侣对佩"},
                    {"id": 5, "name": "花草鱼虫"},
                    {"id": 6, "name": "吉祥寓意"},
                    {"id": 7, "name": "典故传说"}
                ];
                _this.store = localDataService.getStore();
            }
        }

        function search (goodType) {
            goodType && (_this.formatSearchCondition.type = goodType);
            dataService.post(_this.searchUrl, _this.formatSearchCondition)
                .then(function (resp) {
                    _this.items = resp.result;
                });
        }

        function changListMode () {
            _this.listMode = _this.listMode == 'img' ? 'list' : 'img';
        }

        function goToItem (item) {
            if (_this.searchCondition.searchType == 'goods') {
                $state.go('tab.goods', {goodsId: item.id});
            } else if (_this.searchCondition.searchType == 'stores') {
                $state.go('tab.store', {storeId: item.id});
            }
        }

        function loadMore () {
            _this.formatSearchCondition.start = _this.items.length;
            dataService.post(_this.searchUrl, _this.formatSearchCondition)
                .then(function (resp) {
                    if (resp.result.length == 0) {
                        _this.moreDataCanBeLoaded = false;
                    }
                    for (var i in resp.result) {
                        _this.items.push(resp.result[i]);
                    }
                    $scope.$broadcast('scroll.infiniteScrollComplete');
                });
        }

        function showStoreOptions () {
            $ionicActionSheet.show({
                buttons: [
                    {text: '店铺介绍'},
                    {text: '店铺相册'}
                ],
                buttonClicked: function (index) {
                    switch (index) {
                        case 0:

                            break;
                        case 1:
                            $state.go('tab.storeAlbum', {storeId: _this.searchCondition.storeId});
                            break;
                        default :
                            ;
                    }
                }
            })
        }

        function showCategories () {
            for (var i in _this.categories) {
                _this.categories[i].text = _this.categories[i].name;
            }
            if (_this.categories && _this.categories.length) {
                $ionicActionSheet.show({
                    buttons: _this.categories,
                    buttonClicked: function (index) {
                        _this.formatSearchCondition.start = 0;
                        _this.formatSearchCondition.storeCategoryId = _this.categories[i].id;
                        search('sale');
                    }
                })
            }
        }

        function showContactStore () {
            var hideSheet = $ionicActionSheet.show({
                buttons: [
                    {text: '电话'},
                    {text: '留言'}
                ],
                buttonClicked: function (index) {
                    switch (index) {
                        case 0:
                            document.location.href = 'tel:' + _this.store.tel;
                            hideSheet();
                            break;
                        case 1:
                            _leaveMessage();
                            hideSheet();
                            break;
                        default :
                            ;
                    }
                }
            })
        }

        function _formatSearchCondition () {
            var fsc = {
                /*keyword1: '',
                keyword2: '',
                keyword3: '',*/
                start: 0
            };
            if (_this.searchCondition.searchType == 'goods') {
                fsc.type = 'sale';
            }
            // todo ready to integrate search api
            if (_this.searchCondition.hasOwnProperty('keyword')) {
                var arr = _this.searchCondition.keyword.split(/\s+/);
                for (var i in arr) {
                    if (i < 3) {
                        fsc['keyword' + (parseInt(i) + 1)] = arr[i];
                    }
                }
            }
            if (_this.searchCondition.hasOwnProperty('categoryId')) {
                fsc.categoryId = _this.searchCondition.categoryId;
            }
            if (_this.searchCondition.hasOwnProperty('subCategoryId')) {
                fsc.subCategoryId = _this.searchCondition.subCategoryId;
            }
            if (_this.searchCondition.hasOwnProperty('storeId')) {
                fsc.storeId = _this.searchCondition.storeId;
            }
            if (_this.searchCondition.hasOwnProperty('storeCategoryId')) {
                fsc.storeCategoryId = _this.searchCondition.storeCategoryId;
            }
            return fsc;
        }

        function _leaveMessage () {
            $scope.data = {};
            var myPopup = $ionicPopup.show({
                template: '<input auto-focus auto-focus-enable="true" type="text" ng-model="data.msg">',
                title: '留言',
                scope: $scope,
                buttons: [
                    { text: '取消' },
                    {
                        text: '<b>保存</b>',
                        type: 'button-positive',
                        onTap: function(e) {
                            if (!$scope.data.msg) {
                                //don't allow the user to close unless he enters wifi password
                                e.preventDefault();
                            } else {
                                return $scope.data.msg;
                            }
                        }
                    }
                ]
            });
            myPopup.then(function(res) {
                console.log('Tapped!', res);
                // todo leave message
                /*if (!res) {
                    dataService.post('/messages', {type: 'toStore', replyTo: -1, content: res});
                }*/
            });
        }
    }

})();