(function () {
    'use strict';

    angular.module('starter.controllers')
        .controller('TaskCtrl', TaskCtrl);

    TaskCtrl.$inject = ['$scope', '$state', 'dataService', 'localDataService', '$ionicModal', '$stateParams'];

    function TaskCtrl ($scope, $state, dataService, localDataService, $ionicModal, $stateParams) {

        let _this = this;
        this.param = {
          status: 0,
          pageNo: 0,    // 页码，从1开始
          pageSize: 20,  // 页长
          orderBy: 'applied_time',   // 排序字段：0：applied_time，1：hired_time，2：launch_time，3：finished_time，4：payed_time
          orderType: 'desc'  // 排序方式 asc， desc
        };
        this.taskApplies = [];  // 申请列表
        this.totalApplies = 0;  // 总申请数
        this.currentStatus = 0; // 当前状态分类
        this.user = {};          // 账号所有者：个人或企业
        this.currentTaskApply = {}; // 当前申请
        this.comment = {      // 评论对象
          anonymous: false,   // 是否匿名
          subjectId: 0,       // 评价人
          objectId: 0,        // 被评价人
          taskId: 0,          // 任务id
          grade: 0,            // 几颗星
          comment: ''         // 评论内容
        };
        this.feeParam = {    // 结算对象
          id: -1,        // 申请id
          fees: []       // 结算的费用列表
        };

        this.search = search;
        this.switchStatus = switchStatus;
        this.updateStatus = updateStatus;
        this.openComment = openComment;
        this.clickStar = clickStar;
        this.submitComment = submitComment;
        this.openPay = openPay;
        this.addFee = addFee;
        this.switchType = switchType;
        this.deleteFee = deleteFee;
        this.sumFee = sumFee;
        this.submitPay = submitPay;
        this.viewLabor = viewLabor;

        // 评论配置
        _this.modal = null;
        // 打开评论弹框
        _this.openModal = function() {
          _this.modal.show();
        };
        // 关闭评论弹框
        _this.closeModal = function() {
          _this.modal.hide();
        };
        // 结算弹框
        _this.payModal = null;
        // 打开结算弹框
        _this.openPayModal = function() {
          _this.payModal.show();
        };
        // 关闭结算弹框
        _this.closePayModal = function() {
          _this.payModal.hide();
        };

        init();

        function init () {
          _this.user = localDataService.getUser();

          if ($stateParams.status == 6) {
            switchStatus(102);
          } else {
            search();
          }
          // 初始化评论窗口
          initCommentModal();
          // 初始化结算窗口
          initPayModal();
        }

        /**
         * 查询申请列表
         * 5：虚拟状态，用于查询未评价
         * 6：虚拟状态，用于查询历史任务
         */
        function search () {
          _this.param.pageNo++;
          _this.param.status = _this.currentStatus;
          if (_this.currentStatus === 0) {
            _this.param.orderBy = 'applied_time';
          } else if (_this.currentStatus === 1) {
            _this.param.orderBy = 'hired_time';
          }else if (_this.currentStatus === 2) {
            _this.param.orderBy = 'launch_time';
          } else if (_this.currentStatus === 3) {
            _this.param.orderBy = 'finished_time';
          } else if ([4, 5, 101, 102].indexOf(_this.currentStatus) > -1) {
            _this.param.orderBy = 'payed_time';
          }
          dataService.get('/applies', _this.param)
            .then(function (resp) {
              _this.taskApplies = _this.taskApplies.concat(resp.data && resp.data.data);
              _this.totalApplies = resp && resp.data && resp.data.total;
              $scope.$broadcast('scroll.infiniteScrollComplete');
            });
          _getCount();
        }

      /**
       * 切换类型
       * 101: 未评价
       * 102：已评价
       */
      function switchStatus(status) {
        _this.currentStatus = status;
        _this.taskApplies = [];
        _this.totalApplies = 0;
        _this.param.pageNo = 0;
        $scope.$broadcast('scroll.infiniteScrollComplete');
        search();
      }

      /**
       * 改变状态
       * @param taskApply
       * @param status
       * @param abort
       */
      function updateStatus (taskApply, status, abort) {
        dataService.post('/applies/' + taskApply.id + '/process', {status: status, abort: abort})
          .then(function (resp) {
            taskApply.status = status;
            taskApply.abort = abort;
            if (abort != 0 || [2, 20].indexOf(status) == -1) { // abort为1，或者修改状态不为20, 2（申请开始，开始），从当前列表中移除
              _this.taskApplies.splice(_this.taskApplies.indexOf(taskApply), 1);
              _getCount();
            }
          })
      }

      /**
       * 初始化评论弹框
       */
      function initCommentModal () {
        $ionicModal.fromTemplateUrl('../../templates/task/comment.html', {
          scope: $scope,
          animation: 'slide-in-up'
        }).then(function(modal) {
          _this.modal = modal;
        });
        // Cleanup the modal when we're done with it!
        $scope.$on('$destroy', function() {
          _this.modal.remove();
        });
        // Execute action on hide modal
        $scope.$on('modal.hidden', function() {
          // Execute action
        });
        // Execute action on remove modal
        $scope.$on('modal.removed', function() {
          // Execute action
        });
      }

      /**
       * 打开评价
       */
      function openComment (taskApply) {
        _this.currentTaskApply = taskApply;
        _this.openModal();
      }

      /**
       * 打星
       * @param star
       */
      function clickStar (grade) {
        _this.comment.grade = grade;
      }

      /**
       * 提交评论
       */
      function submitComment () {
        _this.comment.taskId = _this.currentTaskApply.id;
        if (_this.user.userType == 1) { // 企业
          _this.comment.subjectId = _this.user.company.companyId; // 评价人
          _this.comment.objectId = _this.currentTaskApply.laborId; // 被评价人
          _this.comment.type = 1;
        }
        if(_this.user.userType == 2) { // 个人
          _this.comment.subjectId = _this.user.userId; // 评价人
          _this.comment.objectId = _this.currentTaskApply.task.company.companyId; // 被评价人
          _this.comment.type = 2;
        }
        dataService.post('/comment/add', _this.comment)
          .then(function (resp) {
            _this.taskApplies.splice(_this.taskApplies.indexOf(_this.currentTaskApply), 1);
            _getCount();
            _this.closeModal();
          })
      }

      /**
       * 初始化结算弹框
       */
      function initPayModal () {
        $ionicModal.fromTemplateUrl('../../templates/task/pay.html', {
          scope: $scope,
          animation: 'slide-in-up'
        }).then(function(modal) {
          _this.payModal = modal;
        });
        // Cleanup the modal when we're done with it!
        $scope.$on('$destroy', function() {
          _this.payModal.remove();
        });
        // Execute action on hide modal
        $scope.$on('modal.hidden', function() {
          // Execute action
        });
        // Execute action on remove modal
        $scope.$on('modal.removed', function() {
          // Execute action
        });
      }

      /**
       * 打开结算窗口
       */
      function openPay (taskApply) {
        _this.currentTaskApply = taskApply;
        _this.openPayModal();
        _this.feeParam.fees.length = 0;
        _this.feeParam.fees.push({
          "taskApplyId": taskApply.id,
          "title": "",
          "type": 1,
          "isPrimary": 0,
          "amount": taskApply.task.wage,
          "quantity": 1
        });
      }

      /**
       * 新增费用
       */
      function addFee (taskApply) {
        _this.feeParam.fees.push({
          "taskApplyId": taskApply.id,
          "title": "",
          "type": 1,
          "isPrimary": 1,
          "amount": '',
          "quantity": 1
        });
      }

      /**
       * 切换计算类型
       * @param fee
       */
      function switchType (fee) {
        fee.type = fee.type == 1 ? -1 : 1;
      }

      /**
       * 删除费用
       * @param fee
       */
      function deleteFee (fee) {
        _this.feeParam.fees.splice(_this.feeParam.fees.indexOf(fee), 1);
      }

      /**
       * 总计费用
       */
      function sumFee () {
        let sum = 0;
        _this.feeParam.fees.forEach(function (fee) {
          if (fee.type == 1) {
            sum += fee.amount * fee.quantity;
          } else {
            sum -= fee.amount * fee.quantity;
          }
        });
        return sum;
      }

      /**
       * 提交评论
       */
      function submitPay () {
        _this.feeParam.id = _this.currentTaskApply.id;
        dataService.post('/applies/fee/save', _this.feeParam)
          .then(function (resp) {
            _this.taskApplies.splice(_this.taskApplies.indexOf(_this.currentTaskApply), 1);
            _getCount();
            _this.closePayModal();
          })
      }

      /**
       * 查看申请人简介
       */
      function viewLabor (laborId) {
        $state.go('tab.labor', {
          laborId: laborId
        });
      }

      /**
       * 查询各状态的数量
       */
      function _getCount () {
        dataService.get('/task/stat', _this.param)
          .then(function (resp) {
            _this.stat = resp.data;
          });

      }
    }

})();
