(function () {
  'use strict';

  angular.module('starter.controllers')
    .controller('TaskPublishCtrl', TaskPublishCtrl);

  TaskPublishCtrl.$inject = ['$scope', '$state', '$stateParams', '$ionicSlideBoxDelegate', 'dataService', 'localDataService', 'ionicDatePicker', '$ionicModal', 'selectorService'];

  function TaskPublishCtrl($scope, $state, $stateParams, $ionicSlideBoxDelegate, dataService, localDataService, ionicDatePicker, $ionicModal, selectorService) {
    var _this = this, dataOption;
    _this.goHome = goHome;
    _this.saveTask = saveTask;
    _this.openDatePicker = openDatePicker;
    _this.isEdit = !!$stateParams.taskId;
    _this.selector = selector;

    init();

    function init() {
      if ($stateParams.taskId) {
        dataService.get('/task/' + $stateParams.taskId)
          .then(function (resp) {
            _this.task = resp.data;
            if(_this.task.expirationTime){
              _this.task.expirationTime = _this.task.expirationTime.replace(/:\d+\.\d/, '');
            }
          });
      } else {
        _this.task = {
          category: {
            categoryId: -1,
            categoryName: ''
          }
        };
      }

      initSelectModal();
    }

    dataOption = {
      callback: function (val) {  //Mandatory
        var date = new Date(val);
        _this.task.expirationTime = date.getFullYear() + '-' + (date.getMonth() + 1) + '-' + (date.getDate() < 10 ? '0' + date.getDate() : date.getDate()) + " 23:59";
      },
      from: new Date(1970, 1, 1),
      to: new Date(),
      inputDate: new Date(),
      mondayFirst: true,
      dateFormat: 'yyyy-MM-dd HH:mm',
      disableWeekdays: [0],
      closeOnSelect: false,
      templateType: 'popup'
    };

    function openDatePicker () {
      ionicDatePicker.openDatePicker(dataOption);
    }

    /**
     * 触发选择器
     * @param key
     */
    function selector(key) {
      if (key === 'category') {
        $scope.options = selectorService.getCategoryData(_this.task);
        $scope.options.current = _this.task.category;
        $scope.changeCategory = changeCategory;
        $scope.changeSubCategory = changeSubCategory;
      } else if (key === 'insurance') {
        $scope.options = selectorService.getInsurance(key, _this.task);
      } else {
        $scope.options = selectorService.getGeoData(key, _this.task);
      }

      $scope.openModal();
    }

    /**
     * 切换分类
     */
    function changeCategory(category) {
      $scope.options.current = category;
      _generateSubCategory(category.categoryId);
    }

    /**
     * 生成二级分类
     */
    function _generateSubCategory(categoryId) {
      $scope.options.subCategories = [];
      $scope.options.categories.forEach(function (category) {
        if (category.subCategories && (categoryId == category.categoryId || categoryId == -1)) {
          $scope.options.subCategories = $scope.options.subCategories.concat(category.subCategories);
        }
      })
    }

    /**
     * 切换二级分类
     */
    function changeSubCategory(subCategory) {
      $scope.options.current = subCategory;
    }

    function checkItem(item) {
      $scope.options.items.forEach(function (v) {
        v.checked = false;
      });
      item.checked = true;
    }

    function saveModal() {
      if ($scope.options.key === 'category') {
        _this.task.categoryId = $scope.options.current.categoryId;
        _this.task.category.categoryId = $scope.options.current.categoryId;
        _this.task.category.categoryName = $scope.options.current.categoryName;
      } else if ($scope.options.key === 'insurance') {
        var selected = $scope.options.items.filter(function (t) {return t.checked});
        _this.task.insurance = selected.length ? selected[0].id : 0;
      }else {
        selectorService.saveGeoData($scope.options, _this.task, 'task', _this.isEdit);
      }

      $scope.closeModal();
    }

    /**
     * 初始化选择弹窗
     */
    function initSelectModal () {

      // 选择器配置
      $scope.modal = null;
      // 打开选择器弹框
      $scope.openModal = function() {
        $scope.modal.show();
      };
      // 关闭选择器弹框
      $scope.closeModal = function() {
        $scope.modal.hide();
      };

      $scope.saveModal = saveModal;
      $scope.checkItem = checkItem;

      $ionicModal.fromTemplateUrl('../../templates/default/selector.html', {
        scope: $scope,
        animation: 'slide-in-up'
      }).then(function(modal) {
        $scope.modal = modal;
      });
      // Cleanup the modal when we're done with it!
      $scope.$on('$destroy', function() {
        $scope.modal.remove();
      });
      // Execute action on hide modal
      $scope.$on('modal.hidden', function() {
        // Execute action
      });
      // Execute action on remove modal
      $scope.$on('modal.removed', function() {
        // Execute action
      });
    }
    /**
     * 返回首页
     */
    function goHome() {
      _this.showMore = false;
      $state.go('tab.home');
    }

    /**
     * 申请工作
     */
    function saveTask() {
      var api = '/task/add';
      if($stateParams.taskId){
        _this.task.taskId = $stateParams.taskId;
        api = '/task/update';
      }
      dataService.post(api, _this.task)
        .then(function (resp) {
          if(resp.code === 200){
            $state.go('tab.home');
          }
        });
    }
  }

})();
