(function () {
  'use strict';

  angular.module('starter.controllers')
    .controller('UserCompleteCtrl', UserCompleteCtrl);

  UserCompleteCtrl.$inject = ['$scope', '$state', 'localDataService', 'dataService', '$ionicModal', '$timeout', 'selectorService'];

  function UserCompleteCtrl($scope, $state, localDataService, dataService, $ionicModal, $timeout, selectorService) {
    var _this = this;

    _this.selector = selector;
    _this.save = save;
    _this.timer = {};

    init();

    function init() {
      if (!localDataService.getUser()) {
        dataService.get('/user/currentUser')
          .then(function (resp) {
            _this.user = resp.data;
            localDataService.setUser(_this.user);
          });
      } else {
        _this.user = localDataService.getUser();
      }
      initSelectModal();
    }

    /**
     * 触发选择器
     * @param key
     */
    function selector(key) {
      var type = _this.user.userType === 2 ? 'labor' : 'company';

      if (key === 'province' || key === 'city' || key === 'district') {
        $scope.options = selectorService.getGeoData(key, _this.user[type]);
      } else {
        $scope.options = selectorService.getData(key);
      }
      $scope.openModal();
    }

    /**
     * 初始化选择弹窗
     */
    function initSelectModal() {

      // 选择器配置
      $scope.modal = null;
      // 打开选择器弹框
      $scope.openModal = function () {
        $scope.modal.show();
      };
      // 关闭选择器弹框
      $scope.closeModal = function () {
        $scope.modal.hide();
      };

      $scope.saveModal = saveModal;
      $scope.checkItem = checkItem;

      $ionicModal.fromTemplateUrl('../../templates/default/selector.html', {
        scope: $scope,
        animation: 'slide-in-up'
      }).then(function (modal) {
        $scope.modal = modal;
      });
      // Cleanup the modal when we're done with it!
      $scope.$on('$destroy', function () {
        $scope.modal.remove();
      });
      // Execute action on hide modal
      $scope.$on('modal.hidden', function () {
        // Execute action
      });
      // Execute action on remove modal
      $scope.$on('modal.removed', function () {
        // Execute action
      });
    }

    function checkItem(item) {
      var items = $scope.options.items,
        key = $scope.options.key;
      if (key === 'skills') {
        item.checked = !item.checked;
      } else {
        items.forEach(function (v) {
          v.checked = false;
        });
        item.checked = true;
      }
    }

    function saveModal() {
      var key = $scope.options.key;
      var type = _this.user.userType === 2 ? 'labor' : 'company';
      if (key === 'province' || key === 'city' || key === 'district') {
        selectorService.saveGeoData($scope.options, _this.user[type], type, false);
      } else {
        selectorService.callback($scope.options);
      }
      $scope.closeModal();
    }

    function save(key) {
      var param = {};
      if (!_this.timer[key]) {
        $timeout.cancel(_this.timer[key]);
        _this.timer[key] = $timeout(function () {
          if (_this.user.labor) {
            param.laborId = _this.user.labor.laborId;
            param[key] = _this.user.labor[key];
            dataService.post('/labor/update', param)
              .then(function (resp) {
                $timeout.cancel(_this.timer[key]);
                delete _this.timer[key];
              });
          } else if (_this.user.company) {
            param.companyId = _this.user.company.companyId;
            param[key] = _this.user.company[key];
            dataService.post('/company/update', param)
              .then(function (resp) {
                $timeout.cancel(_this.timer[key]);
                delete _this.timer[key];
              });
          }
        }, 500);
      }
    }
  }

})();
