(function () {
  'use strict';

  angular.module('starter.controllers')
    .controller('UserIdentifyCtrl', UserIdentifyCtrl);

  UserIdentifyCtrl.$inject = ['$scope', '$state', 'localDataService', 'dataService', 'serverUrl', '$ionicModal', 'selectorService', '$timeout', 'fileUpload'];

  function UserIdentifyCtrl($scope, $state, localDataService, dataService, serverUrl, $ionicModal, selectorService, $timeout, fileUpload) {
    var _this = this, _default;

    _this.selector = selector;
    _this.save = save;
    _this.timer = {};

    _this.photos = {
      frontSide: {},
      backSide: {},
      license: {}
    };
    _this.currImg = 'front';

    init();

    function init() {
      if (!localDataService.getUser()) {
        dataService.get('/user/currentUser')
          .then(function (resp) {
            _this.user = resp.data;
            localDataService.setUser(_this.user);
            setPhoto();
          });
      } else {
        _this.user = localDataService.getUser();
        setPhoto();
      }

      initSelectModal();
    }

    function setPhoto() {
      if (_this.user.labor && _this.user.labor.laborIdentityList) {
        var i, photoList = _this.user.labor.laborIdentityList;
        for (i = 0; i < photoList.length; i++) {
          if (photoList[i].type) {
            _this.photos.backSide = photoList[i];
          } else {
            _this.photos.frontSide = photoList[i];
          }
        }
      }else if(_this.user.company && _this.user.company.license) {
        _this.photos.license = _this.user.company.license;
      }

      $timeout(function () {
        initEvent();
      }, 100);
    }

    function initEvent() {
      var i, fileInputs = document.getElementsByName("file-input");
      if(fileInputs.length){
        for (i = 0; i < fileInputs.length; i++) {
          fileInputs[i].addEventListener("change",function () {
            var file;
            if(_this.currImg === 'back'){
              file = document.getElementsByName("file-input")[1].files[0];
            }else {
              file = document.getElementsByName("file-input")[0].files[0];
            }
            fileUpload.upload(file, saveImage);
          });
        }
      }
    }

    function saveImage (response) {
      if (response && response.code === 200) {
        if (_this.currImg === 'front') {
          response.data.type = 0;
          _this.photos.frontSide = Object.assign(_this.photos.frontSide,response.data);
          savePhoto();
        } else if (_this.currImg === 'back') {
          response.data.type = 1;
          _this.photos.backSide = Object.assign(_this.photos.backSide,response.data);
          savePhoto();
        } else if (_this.currImg === 'license') {
          _this.photos.license = Object.assign(_this.photos.license,response.data);
          saveLicense();
        }
      }
    }

    /**
     * 触发选择器
     * @param key
     */
    function selector(key) {
      $scope.options = selectorService.getData(key);
      $scope.openModal();
    }

    /**
     * 初始化选择弹窗
     */
    function initSelectModal() {
      // 选择器配置
      $scope.modal = null;
      // 打开选择器弹框
      $scope.openModal = function () {
        $scope.modal.show();
      };
      // 关闭选择器弹框
      $scope.closeModal = function () {
        $scope.modal.hide();
      };

      $scope.saveModal = saveModal;
      $scope.checkItem = checkItem;

      $ionicModal.fromTemplateUrl('../../templates/default/selector.html', {
        scope: $scope,
        animation: 'slide-in-up'
      }).then(function (modal) {
        $scope.modal = modal;
      });
      // Cleanup the modal when we're done with it!
      $scope.$on('$destroy', function () {
        $scope.modal.remove();
      });
      // Execute action on hide modal
      $scope.$on('modal.hidden', function () {
        // Execute action
      });
      // Execute action on remove modal
      $scope.$on('modal.removed', function () {
        // Execute action
      });
    }

    function checkItem(item) {
      var items = $scope.options.items,
        key = $scope.options.key;
      if (key === 'skills') {
        item.checked = !item.checked;
      } else {
        items.forEach(function (v) {
          v.checked = false;
        });
        item.checked = true;
      }
    }

    function saveModal() {
      selectorService.callback($scope.options);
      $scope.closeModal();
    }

    function save(key) {
      var param = {};
      if (!_this.timer[key]) {
        $timeout.cancel(_this.timer[key]);
        _this.timer[key] = $timeout(function () {
          if (_this.user.labor) {
            param.laborId = _this.user.labor.laborId;
            param.realName = _this.user.labor.realName;
            param[key] = _this.user.labor[key];
            dataService.post('/labor/update', param)
              .then(function (resp) {
                $timeout.cancel(_this.timer[key]);
                delete _this.timer[key];
              }).finally(function () {
              $timeout.cancel(_this.timer[key]);
            });
          } else if (_this.user.company) {
            param.companyId = _this.user.company.companyId;
            param[key] = _this.user.company[key];
            dataService.post('/company/update', param)
              .then(function (resp) {
                $timeout.cancel(_this.timer[key]);
                delete _this.timer[key];
              }).finally(function () {
              $timeout.cancel(_this.timer[key]);
            });
          }
        }, 500);
      }
    }

    function saveLicense() {
      dataService.post('/company/update', {
        companyId: _this.user.company.companyId,
        companyName: _this.user.company.companyName,
        license: _this.user.company.license
      })
        .then(function (resp) {
        });
    }

    function savePhoto(){
      dataService.post('/labor/update', {
        laborId: _this.user.labor.laborId,
        realName: _this.user.labor.realName,
        laborIdentityList: _this.user.labor.laborIdentityList
      })
        .then(function (resp) {
        });
    }
  }

})();
