(function () {
  'use strict';

  angular.module('starter.controllers')
    .controller('UserProfileCtrl', UserProfileCtrl);

  UserProfileCtrl.$inject = ['$scope', '$state', 'localDataService', 'ionicDatePicker', 'dataService', 'serverUrl', '$ionicModal', 'selectorService', '$timeout', 'fileUpload'];

  function UserProfileCtrl($scope, $state, localDataService, ionicDatePicker, dataService, serverUrl, $ionicModal, selectorService, $timeout, fileUpload) {
    var _this = this, dataOption;

    _this.selector = selector;
    _this.setSkillLabel = setSkillLabel;
    _this.save = save;
    _this.timer = {};

    init();

    /**
     * 初始化方法
     */
    function init() {
      _initData();
      if (!localDataService.getUser()) {
        dataService.get('/user/currentUser')
          .then(function (resp) {
            _this.user = resp.data;
            localDataService.setUser(_this.user);
            bindEvent();
          });
      } else {
        _this.user = localDataService.getUser();
        bindEvent();
      }

      initSelectModal();
    }

    function bindEvent () {
      $timeout(function () {
        initEvent();
      }, 100);
    }

    function initEvent() {
      var i, fileInputs = document.getElementsByName("file-input");
      if(fileInputs.length){
        for (i = 0; i < fileInputs.length; i++) {
          fileInputs[i].addEventListener("change",function () {
            var file = document.getElementsByName("file-input")[0].files[0];
            fileUpload.upload(file, saveImage);
          });
        }
      }
    }

    function saveImage(response) {
      _this.user.avatar = response.data;
      saveAvatar();
    }

    function _initData() {
      /**
       * 日期选择配置
       * @type {{callback: callback, from: Date, to: Date, inputDate: Date, mondayFirst: boolean, dateFormat: string, disableWeekdays: number[], closeOnSelect: boolean, templateType: string}}
       */
      dataOption = {
        callback: function (val) {  //Mandatory
          var date = new Date(val);
          _this.user.labor.birthday = date.getFullYear() + '-' + (date.getMonth() + 1) + '-' + (date.getDate() < 10 ? '0' + date.getDate() : date.getDate());
          save('birthday');
        },
        from: new Date(1970, 1, 1),
        to: new Date(),
        inputDate: new Date(),
        mondayFirst: true,
        dateFormat: 'yyyy-MM-dd',
        disableWeekdays: [0],
        closeOnSelect: false,
        templateType: 'popup'
      };
    }

    /**
     * 显示多条技能
     */
    function setSkillLabel() {
      var i, label = [], skills = _this.user.labor.skills;
      for (i = 0; i < skills.length; i++) {
        label.push(skills[i].skillName);
      }
      return label.join(',');
    }

    /**
     * 打开时间选择
     */
    _this.openDatePicker = function () {
      ionicDatePicker.openDatePicker(dataOption);
    };

    /**
     * 触发选择器
     * @param key
     */
    function selector(key) {
      $scope.options = selectorService.getData(key);
      $scope.openModal();
    }

    /**
     * 初始化选择弹窗
     */
    function initSelectModal() {

      // 选择器配置
      $scope.modal = null;
      // 打开选择器弹框
      $scope.openModal = function () {
        $scope.modal.show();
      };
      // 关闭选择器弹框
      $scope.closeModal = function () {
        $scope.modal.hide();
      };

      $scope.saveModal = saveModal;
      $scope.checkItem = checkItem;

      $ionicModal.fromTemplateUrl('../../templates/default/selector.html', {
        scope: $scope,
        animation: 'slide-in-up'
      }).then(function (modal) {
        $scope.modal = modal;
      });
      // Cleanup the modal when we're done with it!
      $scope.$on('$destroy', function () {
        $scope.modal.remove();
      });
      // Execute action on hide modal
      $scope.$on('modal.hidden', function () {
        // Execute action
      });
      // Execute action on remove modal
      $scope.$on('modal.removed', function () {
        // Execute action
      });
    }

    function checkItem(item) {
      var items = $scope.options.items,
        key = $scope.options.key;
      if (key === 'skills') {
        item.checked = !item.checked;
      } else {
        items.forEach(function (v) {
          v.checked = false;
        });
        item.checked = true;
      }
    }

    function saveModal() {
      selectorService.callback($scope.options);
      $scope.closeModal();
    }

    function save(key) {
      var param = {};
      if(!_this.timer[key]){
        $timeout.cancel(_this.timer[key]);
        _this.timer[key] = $timeout(function () {
          if (_this.user.labor) {
            param.laborId = _this.user.labor.laborId;
            param[key] = _this.user.labor[key];
            dataService.post('/labor/update', param)
              .then(function (resp) {
                $timeout.cancel(_this.timer[key]);
                delete _this.timer[key];
              });
          } else if (_this.user.company) {
            param.companyId = _this.user.company.companyId;
            param[key] = _this.user.company[key];
            dataService.post('/company/update', param)
              .then(function (resp) {
                $timeout.cancel(_this.timer[key]);
                delete _this.timer[key];
              });
          }
        }, 500);
      }
    }

    function saveAvatar() {
      dataService.post('/user/avatar', {
        userId: _this.user.userId,
        username: _this.user.username,
        avatar: _this.user.avatar
      })
        .then(function (resp) {
        });
    }
  }

})();
