(function () {
    'use strict';
    angular.module('starter.services')
        .service('dataService', dataService);

    dataService.$inject = ['$http', '$q', '$log', 'serverUrl', 'localDataService'];

    function dataService ($http, $q, $log, serverUrl, localDataService) {
        var serviceUrl = serverUrl + 'job-serve';

        this.get = get;
        this.post = post;
        this.put = put;
        this.del = del;

        this.gets = gets;

        function get (api, requestData, header) {
            return request('GET', api, requestData, header);
        }

        function post (api, requestData, header) {
            return request('POST', api, requestData, header);
        }

        function put (api, requestData, header) {
            return request('PUT', api, requestData, header);
        }

        function del (api, header) {
            return request('DELETE', api, '', header);
        }

        function request (requestType, api, requestData, header) {
            var d = $q.defer();
            var url = serviceUrl + api;
             //showLoading();
            if (header) {
                $http.defaults.headers.common = header;
            }
            var _token = localDataService.getToken();
            if (_token) {
              if (api.indexOf('smsVerify') < 0 && api.indexOf('login') < 0 && api.indexOf('register') < 0) {
                Object.assign($http.defaults.headers.common, {'Authorization': _token});
              } else {
                Object.assign($http.defaults.headers.common, {});
              }
            }
            var requestBody = {
              method: requestType,
              url: url
            };

            if(requestData){
              if(requestType === 'GET'){
                requestBody.params = requestData;
              }else{
                requestBody.data = requestData;
              }
            }

            $http(requestBody)
                .success(function (data, status, headers, config) {
                    //hideLoading();
                  if(!data || data.code === 401){
                    location.href="#/login";
                  }else{
                    d.resolve(data);
                  }
                })
                .error(function (data, status, headers, config) {
                    //hideLoading();
                    $log.error("Error: ", headers);
                    d.reject(data);
                });
            return d.promise;
        }

        function gets(urls) {
            var d = $q.defer();
            var httpArray = [];
            if(_.isArray(urls)) {
                angular.forEach(urls, function(url) {
                    this.push($http.get(serviceUrl + url));
                }, httpArray);
            } else {
                httpArray.push($http.get(serviceUrl + urls));
            }

            //showLoading();
            $q.all(httpArray).then(function (arrayOfResponses) {
                //hideLoading();
                d.resolve(arrayOfResponses);
            }, function (error) {
                //hideLoading();
                d.reject(error);
            });
            return d.promise;
        }
    }
})();
