(function () {
  'use strict';

  angular.module('starter.services')
    .service('selectorService', selectorService);

  selectorService.$inject = ['dataService', 'localDataService'];

  function selectorService(dataService, localDataService) {
    var self = this;

    self.options = {
      title: {
        skills: '技能选择',
        occupation: '职业选择',
        education: '学历选择',
        jobType: '工作类型',
        gender: '性别选择',
        province: '省份选择',
        city: '城市选择',
        district: '区县选择',
        property: '公司性质选择',
        category: '分类选择',
        insurance: '保险服务'
      },
      api: {
        skills: '/labor/skills',
        occupation: '/labor/occupations',
        province: '/area/0',
        city: '/area/',
        district: '/area/'
      },
      itemArray: {
        education: ['小学', '初中', '高中', '中专', '职校', '中技', '专科', '本科', '硕士研究生', '博士研究生'],
        jobType: ['全职', '兼职'],
        gender: ['男', '女'],
        property: ['公司', '事业单位', '个体工商户', '公益组织', '其他']
      },
      options: {
        jobs: {
          0: '全职',
          1: '兼职'
        },
        insurance: [
          {
            id: 0,
            name:'自愿购买'
          },
          {
            id: 1,
            name:'强制购买'
          }
        ]
      }
    };
    /**
     * 获取备选项
     * @param key
     */
    self.getData = function (key) {
      var i, title, api, items = [],

        user = localDataService.getUser(),
        data = {};
      title = self.options.title[key];
      api = self.options.api[key];
      data.key = key;
      data.title = title;
      if (api) {
        if (user.labor) {
          if (key === 'city') {
            api += user.labor.provinceId || 320000;
          } else if (key === 'district') {
            api += user.labor.cityId || 320500;
          }
        } else if (user.company) {
          if (key === 'city') {
            api += user.company.provinceId || 320000;
          } else if (key === 'district') {
            api += user.company.cityId || 320500;
          }
        }
        dataService.get(api)
          .then(function (resp) {
            data.items = resp.data;
            self.setSelected(data);
          });
      } else {
        for (i = 0; i < self.options.itemArray[key].length; i++) {
          items.push({
            id: self.options.itemArray[key][i],
            name: self.options.itemArray[key][i]
          });
        }
        data.items = items;
        self.setSelected(data);
      }
      return data;
    };

    self.getInsurance = function (key, obj) {
      var title, data = {};
      title = self.options.title[key];
      data.key = key;
      data.title = title;
      data.items = self.options.options[key];
      var i;
      for (i = 0; i < data.items.length; i++) {
        if (obj[data.key] === data.items[i].id) {
          data.items[i].checked = true;
        }
      }
      return data;
    };
    /**
     * 省市区加载
     * @param key
     * @param obj
     */
    self.getGeoData = function (key, obj) {

      var title, api, data = {};
      title = self.options.title[key];
      api = self.options.api[key];
      data.key = key;
      data.title = title;

      if (api && obj) {
        if (key === 'city') {
          api += obj.provinceId || 320000;
        } else if (key === 'district') {
          api += obj.cityId || 320500;
        }
        dataService.get(api)
          .then(function (resp) {
            data.items = resp.data;
            initSelected();
          });
      }

      function initSelected() {
        var i;
        for (i = 0; i < data.items.length; i++) {
          if (obj[data.key] === data.items[i].name) {
            data.items[i].checked = true;
          }
        }
      }
      return data;
    };

    /**
     * category加载
     */
    self.getCategoryData = function (obj){
      var data = {
        key: 'category'
      };
      data.title = self.options.title[data.key];
      dataService.get('/task/categories')
        .then(function (resp) {
          data.categories = resp.data;
          data.categories.unshift({
            categoryId: -1,
            categoryName: '全部分类'
          });
          console.log(obj);
        });
      return data;
    };

    /**
     * 加载已选中项
     * @param param
     */
    self.setSelected = function (param) {
      var i,
        user = localDataService.getUser(),
        items = param.items, label = [],
        key = param.key,
        new_items = [];
      if (key === 'occupation') {
        if (user.labor && !user.labor.occupation){
          user.labor.occupation = {};
        }
        if (user.labor && user.labor.occupation) {
          for (i = 0; i < items.length; i++) {
            if (user.labor && user.labor.occupation && user.labor.occupation.occupationId === items[i].occupationId) {
              items[i].checked = true;
            }
            new_items.push({
              id: items[i].occupationId,
              name: items[i].occupationName,
              checked: !!items[i].checked
            });
          }
        }
        param.items = new_items;
      } else if (key === 'skills') {
        if (user.labor && !user.labor.skills){
          user.labor.skills = {};
        }
        if (user.labor && user.labor.skills) {
          for (i = 0; i < user.labor.skills.length; i++) {
            label.push(user.labor.skills[i].skillName);
          }
          for (i = 0; i < items.length; i++) {
            if (label.indexOf(items[i].skillName) > -1) {
              items[i].checked = true;
            }
            new_items.push({
              id: items[i].skillId,
              name: items[i].skillName,
              checked: !!items[i].checked
            });
          }
        }
        param.items = new_items;
      } else {
        if (user.labor) {
          for (i = 0; i < items.length; i++) {
            if (user.labor[param.key] === items[i].name) {
              items[i].checked = true;
            }
          }
        } else if (user.company) {
          for (i = 0; i < items.length; i++) {
            if (user.company[param.key] === items[i].name) {
              items[i].checked = true;
            }
          }
        }
      }
    };

    /**
     * 选择后的回调
     * 触发保存
     * @param options
     */
    self.callback = function (options) {
      var i, items = options.items,
        key = options.key,
        user = localDataService.getUser(),
        param = {};

      if (key === 'skills') {
        user.labor.skills = [];
        for (i = 0; i < items.length; i++) {
          if (items[i].checked) {
            user.labor.skills.push({
              skillId: items[i].id,
              skillName: items[i].name
            });
          }
        }
      } else if (key === 'occupation') {
        for (i = 0; i < items.length; i++) {
          if (items[i].checked) {
            user.labor.occupation = {
              occupationId: items[i].id,
              occupationName: items[i].name
            };
            break;
          }
        }
      } else {
        for (i = 0; i < items.length; i++) {
          if (items[i].checked) {
            if (user.labor) {
              user.labor[key] = items[i].name;
            } else if (user.company) {
              user.company[key] = items[i].name;
            }
            break;
          }
        }
      }

      if (user.labor) {
        param.laborId = user.labor.laborId;
        param.realName = user.labor.realName;
        param[key] = user.labor[key];
        dataService.post('/labor/update', param)
          .then(function (resp) {
          });
      } else if (user.company) {
        param.companyId = user.company.companyId;
        param.companyName = user.company.companyName;
        param[key] = user.company[key];
        dataService.post('/company/update', param)
          .then(function (resp) {
          });
      }
    };

    /**
     * 保存省市区
     */
    self.saveGeoData = function (options, obj, type, isEdit) {
      var param = {}, i, key = options.key, item;
      for (i = 0; i < options.items.length; i++) {
        if (options.items[i].checked) {
          item = options.items[i];
          break;
        }
      }
      if (key === 'province' && obj[key] !== item.name) {
        obj['city'] = '';
        obj['cityId'] = '';
        obj['district'] = '';
        obj['districtId'] = '';
      }
      if (key === 'city' && obj[key] !== item.name) {
        obj['district'] = '';
        obj['districtId'] = '';
      }
      obj[key] = item.name;
      obj[key + "Id"] = item.id;

      param.province = obj.province;
      param.provinceId = obj.provinceId;
      param.city = obj.city;
      param.cityId = obj.cityId;
      param.district = obj.district;
      param.districtId = obj.districtId;

      if(type === 'labor'){
        param.laborId = obj.laborId;
        param.realName = obj.realName;
        dataService.post('/labor/update', param)
          .then(function (resp) {
          });
      } else if (type === 'company'){
        param.companyId = obj.companyId;
        param.companyName = obj.companyName;
        dataService.post('/company/update', param)
          .then(function (resp) {
          });
      } else if (type === 'task'){
        if (isEdit) {
          param.taskId = obj.taskId;
          param.companyId = obj.companyId;
          dataService.post('/task/update', param)
            .then(function (resp) {
            });
        }
      }
    };

  }

})();
